@@ -2,7 +2,7 @@
 import os
 import sys
 
-from python_qt_binding.QtCore import QObject, pyqtSlot
+from python_qt_binding.QtCore import QObject, Slot
 
 
 class PythonReloader(QObject):
@@ -10,11 +10,12 @@ class PythonReloader(QObject):
         super(PythonReloader, self).__init__(parent)
         self._main = main
 
-    @pyqtSlot()
+    @Slot()
     def restart(self):
         import_dir = os.path.join(os.path.dirname(os.path.realpath(__file__)), '..')
         python_path = os.environ.get('PYTHONPATH', '')
         if import_dir not in python_path:
             python_path += ':{}'.format(import_dir)
         os.environ['PYTHONPATH'] = python_path
-        os.execv(self._main, sys.argv)
+        args = [sys.executable, self._main] + sys.argv[1:]
+        os.execv(sys.executable, args)
